@@ -59,3 +59,29 @@ is_proxy <- function(ip){
   result = fromJSON(py$j1)
   return(result['is_proxy'])
 }
+
+#' @title Lookup for IP address proxy information using IP2Proxy web service.
+#' @param api_key IP2Proxy web service API key
+#' @param ip IPv4 or IPv6 address
+#' @param package Package to use for IP2Proxy web service.
+#' @description Find the country, region, city, ISP, domain name, usage types, asn, as name, last seen, threat type and provider. The return values will be depending on the IP2Proxy web service package used.
+#' @return Return all the proxy information about the IP address
+#' @import reticulate
+#' @import jsonlite
+#' @export
+#' @examples \donttest{
+#' lookup_web_service("8.8.8.8")
+#' }
+#'
+
+lookup_web_service <- function(api_key, ip, package){
+  py_run_string("import IP2Proxy")
+  py_run_string("import json")
+  ws_initialize = paste("ws = IP2Proxy.IP2ProxyWebService('", api_key, "','", package, "',True)", sep = "")
+  py_run_string(ws_initialize)
+  API_result = paste("rec = ws.lookup('", ip, "')", sep = "")
+  py_run_string(API_result)
+  py_run_string("j = json.dumps(rec)")
+  result = fromJSON(py$j)
+  return(result)
+}
